@@ -27,6 +27,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation type="unfinished"></translation>
@@ -65,18 +73,10 @@
         <source>Please license %1</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>The full version allows you to watch videos without interruptions.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Without a license, the application will expire in %1 days.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
         <translation type="unfinished"></translation>
@@ -110,7 +110,7 @@
     <message numerus="yes">
         <source>You have %n new video(s)</source>
         <translation type="unfinished">
-            <numerusform></numerusform>
+            <numerusform></numerusform><numerusform></numerusform>
         </translation>
     </message>
 </context>
@@ -159,6 +159,10 @@
         <source>Show Updated</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation type="unfinished"></translation>
@@ -179,17 +183,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -200,25 +193,44 @@
     <message numerus="yes">
         <source>%n hour(s) ago</source>
         <translation type="unfinished">
-            <numerusform></numerusform>
+            <numerusform></numerusform><numerusform></numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <source>%n day(s) ago</source>
         <translation type="unfinished">
-            <numerusform></numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>%n weeks(s) ago</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
+            <numerusform></numerusform><numerusform></numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <source>%n month(s) ago</source>
         <translation type="unfinished">
-            <numerusform></numerusform>
+            <numerusform></numerusform><numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s) ago</source>
+        <translation type="unfinished">
+            <numerusform></numerusform><numerusform></numerusform>
         </translation>
     </message>
 </context>
@@ -274,7 +286,7 @@
     <message numerus="yes">
         <source>%n Download(s)</source>
         <translation type="unfinished">
-            <numerusform></numerusform>
+            <numerusform></numerusform><numerusform></numerusform>
         </translation>
     </message>
 </context>
@@ -418,6 +430,14 @@
 </context>
 <context>
     <name>MainWindow</name>
+    <message>
+        <source>&amp;Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Minimize</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>&amp;Stop</source>
         <translation type="unfinished"></translation>
@@ -658,6 +678,14 @@
         <source>Hide videos that may contain inappropriate content</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
         <translation type="unfinished"></translation>
@@ -746,6 +774,10 @@
         <source>Remaining time: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Volume at %1%</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Volume is muted</source>
         <translation type="unfinished"></translation>
@@ -778,26 +810,10 @@
         <source>Update</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Toggle &amp;Menu Bar</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>You can still access the menu bar by pressing the ALT key</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Window</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Minimize</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Menu</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -844,6 +860,10 @@
         <source>Subscribe to %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation type="unfinished"></translation>
@@ -852,6 +872,18 @@
         <source>Subscribed to %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rewind %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fast forward %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>channel</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MessageWidget</name>
@@ -879,10 +911,6 @@
         <source>Install Update</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Pick a video</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>PasteLineEdit</name>
@@ -892,11 +920,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
+        <source>Pick a video</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation type="unfinished"></translation>
@@ -936,10 +967,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation type="unfinished"></translation>
@@ -1061,7 +1088,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Enter</source>
+        <source>to start watching videos.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1069,11 +1096,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>to start watching videos.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Watch</source>
+        <source>Enter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1088,6 +1111,18 @@
         <source>Get the full version</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Need a remote control for %1? Try %2!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I keep improving %1 to make it the best I can. Support this work!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SidebarHeader</name>
@@ -1095,6 +1130,10 @@
         <source>&amp;Back</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation type="unfinished"></translation>
