@@ -25,6 +25,14 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Käännä %1 äidinkielellesi käyttämällä %2</translation>
     </message>
+    <message>
+        <source>Powered by %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open-source software</source>
+        <translation>Avoimen lähdekoodin ohjelmisto</translation>
+    </message>
     <message>
         <source>Icon designed by %1.</source>
         <translation>Kuvakkeen suunnitteli %1.</translation>
@@ -107,7 +115,7 @@
     </message>
     <message numerus="yes">
         <source>You have %n new video(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Sinulle on %n uusi video</numerusform><numerusform>Sinulle on %n uutta videota</numerusform></translation>
     </message>
 </context>
 <context>
@@ -155,6 +163,10 @@
         <source>Show Updated</source>
         <translation>Näytä päivitetyt</translation>
     </message>
+    <message>
+        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
+        <translation>Sinulla ei ole tilauksia. Käytä tähtisymbolia tilataksesi kanavia.</translation>
+    </message>
     <message>
         <source>All Videos</source>
         <translation>Kaikki videot</translation>
@@ -175,17 +187,6 @@
         <source>There are no updated subscriptions at this time.</source>
         <translation>Päivitettyjä tilauksia ei ole tällä hetkellä.</translation>
     </message>
-    <message>
-        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
-        <translation>Sinulla ei ole tilauksia. Käytä tähtisymbolia tilataksesi kanavia.</translation>
-    </message>
-</context>
-<context>
-    <name>ClearButton</name>
-    <message>
-        <source>Clear</source>
-        <translation>Tyhjennä</translation>
-    </message>
 </context>
 <context>
     <name>DataUtils</name>
@@ -195,19 +196,38 @@
     </message>
     <message numerus="yes">
         <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n tunti sitten</numerusform><numerusform>%n tuntia sitten</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n weeks(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n päivä sitten</numerusform><numerusform>%n päivää sitten</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>%n month(s) ago</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n kuukausi sitten</numerusform><numerusform>%n kuukautta sitten</numerusform></translation>
+    </message>
+    <message>
+        <source>K</source>
+        <comment>K as in Kilo, i.e. thousands</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>M</source>
+        <comment>M stands for Millions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>B</source>
+        <comment>B stands for Billions</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 views</source>
+        <translation>Katsottu %1 kertaa</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s) ago</source>
+        <translation><numerusform>%n viikko sitten</numerusform><numerusform>%n viikkoa sitten</numerusform></translation>
     </message>
 </context>
 <context>
@@ -251,22 +271,6 @@
 </context>
 <context>
     <name>DownloadManager</name>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Tämä on vain %1-kokeiluversio.</translation>
-    </message>
-    <message>
-        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation>Voit ladata vain videoita jotka ovat lyhyempiä kuin %1 minuuttia, jotta voit testata latausominaisuutta.</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Jatka</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Hanki täysi versio</translation>
-    </message>
     <message>
         <source>%1 downloaded in %2</source>
         <translation>%1 ladattu ajassa %2</translation>
@@ -277,7 +281,7 @@
     </message>
     <message numerus="yes">
         <source>%n Download(s)</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>%n lataus</numerusform><numerusform>%n latausta</numerusform></translation>
     </message>
 </context>
 <context>
@@ -632,10 +636,6 @@
         <source>&amp;Float on Top</source>
         <translation>&amp;Pysy päällimmäisenä</translation>
     </message>
-    <message>
-        <source>&amp;Adjust Window Size</source>
-        <translation>&amp;Muuta ikkunan kokoa</translation>
-    </message>
     <message>
         <source>&amp;Stop After This Video</source>
         <translation>Py&amp;säytä toisto tämän videon jälkeen</translation>
@@ -666,11 +666,19 @@
     </message>
     <message>
         <source>Restricted Mode</source>
-        <translation type="unfinished"/>
+        <translation>Rajoitettu tila</translation>
     </message>
     <message>
         <source>Hide videos that may contain inappropriate content</source>
-        <translation type="unfinished"/>
+        <translation>Piilota videot, jotka saattavat sisältää soveltumatonta sisältöä</translation>
+    </message>
+    <message>
+        <source>Toggle &amp;Menu Bar</source>
+        <translation>Näytä/piilota &amp;valikkopalkki</translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation>Valikko</translation>
     </message>
     <message>
         <source>&amp;Love %1? Rate it!</source>
@@ -796,6 +804,10 @@
         <source>Update</source>
         <translation>Päivitä</translation>
     </message>
+    <message>
+        <source>You can still access the menu bar by pressing the ALT key</source>
+        <translation>Saat valikkopalkin näkyviin painamalla ALT-näppäintä</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -811,22 +823,6 @@
         <source>The link will be valid only for a limited time.</source>
         <translation>Osoite on käytössä vain rajoitetun ajan.</translation>
     </message>
-    <message>
-        <source>This is just the demo version of %1.</source>
-        <translation>Tämä on vain %1n kokeiluversio.</translation>
-    </message>
-    <message>
-        <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Voit kokeilla ohjelmaa nähdäksesi, toimiiko se.</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Hanki täysi versio</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Jatka</translation>
-    </message>
     <message>
         <source>Downloading %1</source>
         <translation>Ladataan %1ta/tä</translation>
@@ -858,6 +854,10 @@
         <source>Subscribe to %1</source>
         <translation>Tilaa kanava %1</translation>
     </message>
+    <message>
+        <source>Switched to %1</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Unsubscribed from %1</source>
         <translation>Kohteen %1 tilaus lopetettu</translation>
@@ -902,11 +902,14 @@
     </message>
 </context>
 <context>
-    <name>PlaylistItemDelegate</name>
+    <name>PickMessage</name>
     <message>
-        <source>%1 views</source>
-        <translation>Katsottu %1 kertaa</translation>
+        <source>Pick a video</source>
+        <translation>Valitse video</translation>
     </message>
+</context>
+<context>
+    <name>PlaylistItemDelegate</name>
     <message>
         <source>%1 of %2 (%3) — %4</source>
         <translation>%1 / %2 (%3) — %4</translation>
@@ -946,10 +949,6 @@
 </context>
 <context>
     <name>PlaylistModel</name>
-    <message>
-        <source>Searching...</source>
-        <translation>Etsitään...</translation>
-    </message>
     <message>
         <source>Show %1 More</source>
         <translation>Näytä %1 lisää</translation>
@@ -1071,25 +1070,16 @@
         <translation>Tervetuloa &lt;a href=&apos;%1&apos;&gt;%2en&lt;/a&gt;</translation>
     </message>
     <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation>Syötä</translation>
+        <source>to start watching videos.</source>
+        <translation>aloittaaksesi videoiden katselu.</translation>
     </message>
     <message>
         <source>a keyword</source>
         <translation>hakusana</translation>
     </message>
     <message>
-        <source>a channel</source>
-        <translation>kanava</translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation>aloittaaksesi videoiden katselu.</translation>
-    </message>
-    <message>
-        <source>Watch</source>
-        <translation>Katso</translation>
+        <source>Enter</source>
+        <translation>Syötä</translation>
     </message>
     <message>
         <source>Recent keywords</source>
@@ -1110,6 +1100,10 @@
         <source>&amp;Back</source>
         <translation>&amp;Takaisin</translation>
     </message>
+    <message>
+        <source>&amp;Forward</source>
+        <translation>&amp;Eteenpäin</translation>
+    </message>
     <message>
         <source>Forward to %1</source>
         <translation>Eteenpäin kohteeseen %1</translation>
@@ -1163,13 +1157,6 @@
         <translation>Ladataan %1...</translation>
     </message>
 </context>
-<context>
-    <name>Video</name>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation>Videostriimiä ei saada kohteelle %1</translation>
-    </message>
-</context>
 <context>
     <name>YTRegions</name>
     <message>
@@ -1365,4 +1352,11 @@
         <translation>Maailmanlaajuinen</translation>
     </message>
 </context>
+<context>
+    <name>YTVideo</name>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Videostriimiä ei saada kohteelle %1</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
