@@ -21,31 +21,23 @@ $END_LICENSE */
 #ifndef ABOUTVIEW_H
 #define ABOUTVIEW_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
-#include "view.h"
+
 #include "constants.h"
+#include "view.h"
 
 class AboutView : public View {
-
     Q_OBJECT
 
 public:
     AboutView(QWidget *parent);
     void appear();
-    QHash<QString, QVariant> metadata() {
-        QHash<QString, QVariant> metadata;
-        metadata.insert("title", tr("About"));
-        return metadata;
+    const QString &getTitle() {
+        static const QString s = tr("About");
+        return s;
     }
 
-protected:
-    void paintEvent(QPaintEvent *e);
-
 private:
     QPushButton *closeButton;
-
 };
 #endif
