@@ -40,6 +40,16 @@ Http &HttpUtils::yt() {
     return *h;
 }
 
+Http &HttpUtils::stealthAndNotCached() {
+    static Http *h = [] {
+        Http *http = new Http;
+        http->addRequestHeader("User-Agent", stealthUserAgent());
+
+        return http;
+    }();
+    return *h;
+}
+
 void HttpUtils::clearCaches() {
     LocalCache::instance("yt")->clear();
     LocalCache::instance("http")->clear();
@@ -56,6 +66,8 @@ const QByteArray &HttpUtils::userAgent() {
 }
 
 const QByteArray &HttpUtils::stealthUserAgent() {
-    static const QByteArray ua = "curl/7.37.0";
+    static const QByteArray ua =
+            "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like "
+            "Gecko) Chrome/79.0.3945.79 Safari/537.36";
     return ua;
 }
