@@ -679,7 +679,7 @@ void MainWindow::createActions() {
         // add actions to the MainWindow so that they work
         // when the menu is hidden
         addAction(action);
-        MainWindow::instance()->setupAction(action);
+        setupAction(action);
     }
 }
 
@@ -1093,7 +1093,7 @@ void MainWindow::visitSite() {
 }
 
 void MainWindow::donate() {
-    QUrl url(QString(Constants::WEBSITE) + "#donate");
+    QUrl url("https://" + QLatin1String(Constants::ORG_DOMAIN) + "/donate");
     showMessage(QString(tr("Opening %1").arg(url.toString())));
     QDesktopServices::openUrl(url);
 }
@@ -1121,7 +1121,6 @@ void MainWindow::quit() {
     ChannelAggregator::instance()->stop();
     ChannelAggregator::instance()->cleanup();
     Database::shutdown();
-    HttpUtils::clearCaches();
     qApp->quit();
 }
 
